@@ -10,10 +10,10 @@
 
 #include "contacteditor.h"
 
-#include <collectioncombobox.h>
-#include <item.h>
+#include <Akonadi/CollectionComboBox>
+#include <Akonadi/Item>
 
-#include <kcontacts/addressee.h>
+#include <KContacts/Addressee>
 
 #include <KConfig>
 #include <KLocalizedString>
@@ -28,19 +28,19 @@
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN ContactEditorDialog::Private
+class Akonadi::ContactEditorDialogPrivate
 {
 public:
-    Private(ContactEditorDialog::Mode mode,
-            ContactEditorDialog::DisplayMode displaymode,
-            ContactEditor::AbstractContactEditorWidget *editorWidget,
-            ContactEditorDialog *parent)
+    ContactEditorDialogPrivate(ContactEditorDialog::Mode mode,
+                               ContactEditorDialog::DisplayMode displaymode,
+                               ContactEditor::AbstractContactEditorWidget *editorWidget,
+                               ContactEditorDialog *parent)
         : q(parent)
         , mMode(mode)
     {
         auto mainWidget = new QWidget(q);
 
-        q->setWindowTitle(mode == ContactEditorDialog::CreateMode ? i18n("New Contact") : i18n("Edit Contact"));
+        q->setWindowTitle(mode == ContactEditorDialog::CreateMode ? i18nc("@title:window", "New Contact") : i18nc("@title:window", "Edit Contact"));
         auto mainLayout = new QVBoxLayout(q);
         auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         q->connect(buttonBox, &QDialogButtonBox::accepted, q, [this]() {
@@ -54,7 +54,7 @@ public:
         mainLayout->addWidget(buttonBox);
 
         auto layout = new QGridLayout(mainWidget);
-        layout->setContentsMargins(0, 0, 0, 0);
+        layout->setContentsMargins({});
 
         if (editorWidget) {
             mEditor = new AkonadiContactEditor(mode == ContactEditorDialog::CreateMode ? AkonadiContactEditor::CreateMode : AkonadiContactEditor::EditMode,
@@ -80,11 +80,11 @@ public:
         layout->addWidget(mEditor, 1, 0, 1, 2);
         layout->setColumnStretch(1, 1);
 
-        connect(mEditor, &AkonadiContactEditor::contactStored, q, &ContactEditorDialog::contactStored);
+        QObject::connect(mEditor, &AkonadiContactEditor::contactStored, q, &ContactEditorDialog::contactStored);
 
-        connect(mEditor, &AkonadiContactEditor::error, q, &ContactEditorDialog::error);
+        QObject::connect(mEditor, &AkonadiContactEditor::error, q, &ContactEditorDialog::error);
 
-        connect(mEditor, &AkonadiContactEditor::finished, q, [this]() {
+        QObject::connect(mEditor, &AkonadiContactEditor::finished, q, [this]() {
             slotFinish();
         });
 
@@ -126,32 +126,31 @@ public:
 
     ContactEditorDialog *const q;
     CollectionComboBox *mAddressBookBox = nullptr;
-    ContactEditorDialog::Mode mMode;
+    const ContactEditorDialog::Mode mMode;
     AkonadiContactEditor *mEditor = nullptr;
 };
 
 ContactEditorDialog::ContactEditorDialog(Mode mode, QWidget *parent)
     : QDialog(parent)
-    , d(new Private(mode, FullMode, nullptr, this))
+    , d(new ContactEditorDialogPrivate(mode, FullMode, nullptr, this))
 {
 }
 
 ContactEditorDialog::ContactEditorDialog(Mode mode, ContactEditor::AbstractContactEditorWidget *editorWidget, QWidget *parent)
     : QDialog(parent)
-    , d(new Private(mode, FullMode, editorWidget, this))
+    , d(new ContactEditorDialogPrivate(mode, FullMode, editorWidget, this))
 {
 }
 
 ContactEditorDialog::ContactEditorDialog(Mode mode, DisplayMode displayMode, QWidget *parent)
     : QDialog(parent)
-    , d(new Private(mode, displayMode, nullptr, this))
+    , d(new ContactEditorDialogPrivate(mode, displayMode, nullptr, this))
 {
 }
 
 ContactEditorDialog::~ContactEditorDialog()
 {
     d->writeConfig();
-    delete d;
 }
 
 void ContactEditorDialog::setContact(const Akonadi::Item &contact)
@@ -176,8 +175,12 @@ AkonadiContactEditor *ContactEditorDialog::editor() const
 void ContactEditorDialog::accept()
 {
     if (d->mEditor->hasNoSavedData()) {
-        if (KMessageBox::questionYesNo(this, i18nc("@info", "Location was not saved. Do you want to close editor?"), i18nc("@title:window", "Confirmation"))
-            == KMessageBox::No) {
+        const int answer = KMessageBox::questionYesNo(this,
+                                                      i18nc("@info", "Location was not saved. Do you want to close editor?"),
+                                                      i18nc("@title:window", "Confirmation"),
+                                                      KGuiItem(i18nc("@action:button", "Close Editor"), QStringLiteral("dialog-close")),
+                                                      KGuiItem(i18nc("@action:button", "Do Not Close"), QStringLiteral("dialog-cancel")));
+        if (answer == KMessageBox::No) {
             return;
         }
     }
@@ -189,7 +192,13 @@ void ContactEditorDialog::accept()
 
 void ContactEditorDialog::reject()
 {
-    if (KMessageBox::questionYesNo(this, i18nc("@info", "Do you really want to cancel?"), i18nc("@title:window", "Confirmation")) == KMessageBox::Yes) {
+    const int answer = KMessageBox::questionYesNo(this,
+                                                  i18nc("@info", "Do you really want to cancel?"),
+                                                  i18nc("@title:window", "Confirmation"),
+                                                  KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
+                                                  KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
+
+    if (answer == KMessageBox::Yes) {
         QDialog::reject(); // Discard current changes
     }
 }
