@@ -108,8 +108,7 @@ public:
                                             StandardActionManager::ErrorMessageTitle,
                                             i18n("Address book folder creation failed"));
             mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)
-                ->setProperty("ContentMimeTypes",
-                              QStringList() << QStringLiteral("application/x-vnd.kde.contactgroup") << QStringLiteral("text/directory"));
+                ->setProperty("ContentMimeTypes", QStringList() << QStringLiteral("application/x-vnd.kde.contactgroup") << QStringLiteral("text/directory"));
 
             break;
         case Akonadi::StandardActionManager::CopyCollections:
