@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -112,9 +112,7 @@ BusinessEditorWidget::BusinessEditorWidget(QWidget *parent)
     connect(mOrganizationWidget, &KLineEdit::textChanged, this, &BusinessEditorWidget::organizationChanged);
 }
 
-BusinessEditorWidget::~BusinessEditorWidget()
-{
-}
+BusinessEditorWidget::~BusinessEditorWidget() = default;
 
 void BusinessEditorWidget::loadContact(const KContacts::Addressee &contact)
 {
